/*
 * Title:        GridSim Toolkit
 * Description:  GridSim (Grid Simulation) Toolkit for Modeling and Simulation 
 *               of Parallel and Distributed Systems such as Clusters and Grids
 * Licence:      GPL - http://www.gnu.org/copyleft/gpl.html
 *
 * $Id: GridSimTags.java,v 1.8 2003/06/30 05:21:01 anthony Exp $
 */

package gridsim;

/**
 * Contains various static command tags that indicate a type of action that 
 * needs to be undertaken by GridSim entities when they receive events.
 *
 * @author       Manzur Murshed and Rajkumar Buyya
 * @version      2.1, June 2003
 * @invariant $none
 */
public class GridSimTags 
{
    /** Schedules an entity without any delay */
    public static final double SCHEDULE_NOW = 0.0;  

    /** Denotes the end of simulation */
    public static final int END_OF_SIMULATION = -1;
    
    /** 
     * Denotes insignificant simulation entity or time. This tag will not be
     * used for identification purposes. 
     */
    public static final int INSIGNIFICANT = 0; 
    
    /** Sends an Experiment object between UserEntity and Broker entity */
    public static final int EXPERIMENT = 1; 
    
    /** 
     * Denotes a resource to be registered. This tag is normally used between
     * GridInformationService and GridResouce entity.
     */
    public static final int REGISTER_RESOURCE = 2; 
    
    /** 
     * Denotes a list of resources. This tag is normally used between
     * GridInformationService and GridSim entity.
     */ 
    public static final int RESOURCE_LIST = 3; 
    
    /**
     * Denotes grid resource characteristics information. This tag is normally
     * used between GridSim and GridResource entity.
     */
    public static final int RESOURCE_CHARACTERISTICS = 4; 
    
    /**
     * Denotes grid resource allocation policy. This tag is normally
     * used between GridSim and GridResource entity.
     */
    public static final int RESOURCE_DYNAMICS = 5; 
    
    /**
     * Denotes the submission of a Gridlet. This tag is normally
     * used between GridSim and GridResource entity.
     */
    public static final int GRIDLET_SUBMIT = 6; 
    
    /**
     * Denotes the return of a Gridlet back to sender. This tag is 
     * normally used by GridResource entity.
     */
    public static final int GRIDLET_RETURN = 7;
     
    /** Denotes the status of a Gridlet. */
    public static final int GRIDLET_STATUS = 8; 
    
    /** 
     * Denotes a request to record events for statistical purposes. This tag is
     * normally used between GridSim and GridStatistics entity.
     */
    public static final int RECORD_STATISTICS = 9; 
    
    /** Denotes a request to get a statistical list */
    public static final int RETURN_STAT_LIST = 10; 
    
    /** 
     * Denotes a request to send an Accumulator object based on category into
     * an event scheduler. This tag is normally used between ReportWriter and
     * GridStatistics entity.
     */
    public static final int RETURN_ACC_STATISTICS_BY_CATEGORY = 11; 
    
    /** Denotes the default baud rate for some GridSim entities */
    public static final int DEFAULT_BAUD_RATE = 9600; 
    
    /**
     * Private Constructor
     */
    private GridSimTags() {
        // empty
    }
    
} // end class

