/*
 * Title:        GridSim Toolkit
 * Description:  GridSim (Grid Simulation) Toolkit for Modeling and Simulation 
 *               of Parallel and Distributed Systems such as Clusters and Grids
 * Licence:      GPL - http://www.gnu.org/copyleft/gpl.html
 *
 * $Id: PEList.java,v 1.6 2003/06/30 05:21:02 anthony Exp $
 */

package gridsim;

import java.util.LinkedList;

/**
 * GridSim PEList maintains a list of PEs (Processing Elements) that make up
 * a machine.
 *
 * @author       Manzur Murshed and Rajkumar Buyya
 * @version      2.1, June 2003
 * @invariant $none
 */
public class PEList extends LinkedList
{
    /**
     * Allocates a new PEList object
     * @pre $none
     * @post $none
     */
    public PEList() {
        super();
    }

    /**
     * Gets MIPS Rating for a specified PE ID 
     * @param id    the PE ID
     * @return the MIPS rating if exists, otherwise returns -1
     * @deprecated As of GridSim 2.1, replaced by {@link #getMIPSRating(int)}
     * @pre id >= 0
     * @post $none
     */
    public int GetMIPSRating(int id) {
        return this.getMIPSRating(id);
    }
    
    /**
     * Gets MIPS Rating for a specified PE ID 
     * @param id    the PE ID
     * @return the MIPS rating if exists, otherwise returns -1
     * @pre id >= 0
     * @post $none
     */
    public int getMIPSRating(int id) 
    {
        for (int i = 0; i < super.size(); i++) 
        {
            PE obj = (PE) super.get(i);
            if (obj.getID() == id) {
                return obj.getMIPSRating();
            }
        }

        return -1;  // no PE with given id
    }

    /**
     * Gets a PE ID which is FREE 
     * @return a PE ID if it is FREE, otherwise returns -1
     * @deprecated As of GridSim 2.1, replaced by {@link #getFreePEID()}
     * @pre $none
     * @post $none
     */
    public int GetFreePEID() {
        return this.getFreePEID();
    }
    
    /**
     * Gets a PE ID which is FREE 
     * @return a PE ID if it is FREE, otherwise returns -1
     * @pre $none
     * @post $none
     */
    public int getFreePEID()
    {
        for (int i = 0; i < super.size(); i++) 
        {
            PE obj = (PE) super.get(i);
            if (obj.getStatus() == PE.FREE) {
                return i;
            }    
        }
        
        return -1; 
    }

    /**
     * Gets the byte size of PEList internal data members
     * @return the byte size
     * @deprecated As of GridSim 2.1, replaced by {@link #getByteSize()}
     * @pre $none
     * @post $result >= 0
     */
    public int ByteSize() {
        return this.getByteSize();
    }
    
    /**
     * Gets the byte size of PEList internal data members
     * @return the byte size
     * @pre $none
     * @post $result >= 0
     */
    public int getByteSize() {
        return super.size() * PE.getByteSize();
    }
    
} // end class

